import random

number = (1, 2, 3, 4, 5, 6, 7, 8, 9, 10)
pinput = None
cinput = None
odeve = None
c_score = 0
p_score = 0



def odeve():
     while True:
          odeve = input('Odd or even?: ').strip().capitalize()

          if odeve in ['O', 'Odd'] :
              if odd():
                  return


          elif odeve in ['E', 'Even']:
               if even():
                   return

          else:
               print('Wrong input Mfer')

               
def odd():
     global p_score, c_score
     pinput = int(input('Choose a number between 1 - 10: '))

     if pinput not in number:
         print('You stupid ni**a')
         return 

     cinput = random.choice(number)

     print(f"You chose - {pinput}")
     print(f"computer chose - {cinput}")
     print(f"Sum of the numbers - {pinput + cinput}")

     if (pinput + cinput) % 2 == 0:
      c_score += 1
      print(f"You - {p_score}  {c_score} - Computer")
      print('----You Lost!!----')

     else:
      p_score += 1
      print(f"You - {p_score}  {c_score} - Computer")
      print('----You Won----')


     if p_score == 3:
      print('Player Won')
      return 

     elif c_score == 3:
      print('Comnputer Won')
      return 

def even():
     global p_score, c_score
     pinput = int(input('Choose a number between 1 or 10: '))

     if pinput not in number: 
      print('You stupid ni**er')
      return
          
     cinput = random.choice(number)

     print(f"You chose - {pinput}")
     print(f"Computer chose - {cinput}")
     print(f"Sum of the number - {pinput + cinput}")

     if (pinput + cinput) % 2 == 0:
      p_score += 1
      print('----You won----')
      print(f"You - {p_score}  {c_score} - Computer")
      
     else:
      c_score += 1
      print('----You Lost!!----')
      print(f"You - {p_score}  {c_score} - Computer")


     if p_score == 3:
         print('Player Won')
         return 

     elif c_score == 3:
         print('Computer Won')
         return


import random
numbers_g = list(range(1, 101))

def g_game():
    cinput = random.choice(numbers_g)

    print('Computer has chosen a number between 1-100 and you have to guess it in 5 tries or less')
    global tries

    while True:
        pinput = int(input('Choose a number: '))

        if pinput not in numbers_g:
            print('is yo ah dum??')

        if pinput > cinput:
            tries -= 1
            print('Lower')
            print(f"{tries} Tries left")

        elif pinput < cinput:
            tries -= 1
            print('Higher')
            print(f"{tries} Tries left")

        else:
            print("You've guessed it right mg")
            break

        if tries == 0:
            print('No mo tries left')

        else:
            continue


import random

def rps():
   list = ['R', 'Rock', 'P', 'Paper', 'S' 'Scissor']
   pinput = None
   cinput = None
   p_score = 0
   c_score = 0

   while True: 

    pinput = input('Choose (Rock, Paper, Scissor) or q to quit: ').strip().capitalize()

    if pinput == "Q":
       break

    if pinput not in list:
       print("Wtf is wrong w you nigga")
       continue
    
    cinput = random.choice(list)

    print(f"Player chose: {pinput}" )
    print(f"Computer chose: {cinput}" )

    if pinput == cinput:
      print("It's a tie")

    elif (pinput == 'Rock' and cinput == "Scissor") or \
         (pinput == 'Paper' and cinput == "Rock") or \
         (pinput == 'Scissor' and cinput == "Paper"):
        print("You win!")
        p_score += 1
    else:
        print("You lose!")
        c_score += 1

    print(f"Your Score: {p_score} - Computer Score: {c_score}")

    if (p_score == 0 and c_score == 3) or \
       (p_score == 1 and c_score == 3) or \
       (p_score == 2 and c_score == 3):
       print('----You Lost!----')
       break

    elif (p_score == 3 and c_score == 0) or \
         (p_score == 3 and c_score == 1) or \
         (p_score == 3 and c_score == 2):
         print('----You Won!!----')
         break

    else:
       continue



import random

numbers_f = list(range(1, 11))


def smart_choice(total):
     safe_points = [6, 17, 28, 39]

     for sp in safe_points:
        if total < sp <= total + 10:
            return sp - total 
        
     return random.choice(numbers_f)


def f2f():
     print("Let's play a game, you and i choose a number, whoevers numbers add to 50 loses")

     total = 0

     while True:
        try:
            pinput = int(input('Choose a number between 1-10: '))
        
        except ValueError:
            print('Is you retarded mfer??')
            continue
        
        if pinput not in numbers_f:
            print('f off bruh')
            continue
        
        total += pinput 
        print(f"You chose - {pinput}, total = {total}")

        if total >= 50:
            print("haha loser!!")
            break

        cinput = smart_choice(total)
        total += cinput
        print(f"I chose - {cinput}, total = {total}")

        if total >= 50:
            print('You won by luck, My guy')
            break